using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace Solar_System
{
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Vector2 velocity;
        public Color color;

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            color = Color.White;
        }

        public bool Load(string assetName)
        {
            try
            {
                image = p_content.Load<Texture2D>(assetName);
            }
            catch (Exception) { return false; }
            return true;
        }

        public void Draw()
        {
            p_spriteBatch.Draw(image, position, color);
        }

        public void Move()
        {
            position += velocity;
        }
    }

    public class Planet : Sprite
    {
        public float radius;
        public float angle;
        public float velocity;

        public Planet(ContentManager content, SpriteBatch spriteBatch)
            : base(content, spriteBatch)
        {
            radius = 0.0f;
            angle = 0.0f;
            velocity = 0.0f;
        }
    }

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Viewport screen;
        Sprite sun;
        List<Planet> planets;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            screen = GraphicsDevice.Viewport;

            //create sun sprite
            sun = new Sprite(Content, spriteBatch);
            sun.Load("sun");
            sun.position = new Vector2((screen.Width - sun.image.Width)/2, 
                (screen.Height - sun.image.Height)/2);

            //create planet sprites
            planets = new List<Planet>();

            //add 1st planet
            Planet planet = new Planet(Content, spriteBatch);
            planet.Load("planet1");
            planet.velocity = 0.2f;
            planet.radius = 100;
            planet.angle = MathHelper.ToRadians(30);
            planets.Add(planet);

            //add 2nd planet
            planet = new Planet(Content, spriteBatch);
            planet.Load("planet2");
            planet.velocity = 0.16f;
            planet.radius = 140;
            planet.angle = MathHelper.ToRadians(60);
            planets.Add(planet);

            //add 3rd planet
            planet = new Planet(Content, spriteBatch);
            planet.Load("planet3");
            planet.velocity = 0.06f;
            planet.radius = 195;
            planet.angle = MathHelper.ToRadians(90);
            planets.Add(planet);

            //add 4th planet
            planet = new Planet(Content, spriteBatch);
            planet.Load("planet4");
            planet.velocity = 0.01f;
            planet.radius = 260;
            planet.angle = MathHelper.ToRadians(120);
            planets.Add(planet);

        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //update planet orbits
            foreach (Planet planet in planets)
            {
                planet.angle += planet.velocity;

                float orbitx = (float)(Math.Cos(planet.angle) * planet.radius);
                float orbity = (float)(Math.Sin(planet.angle) * planet.radius);

                float x = (screen.Width - planet.image.Width) / 2 + orbitx;
                float y = (screen.Height - planet.image.Height) / 2 + orbity; 

                planet.position = new Vector2(x, y);
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            //draw the sun
            sun.Draw();

            //draw the planets
            foreach (Planet planet in planets)
            {
                planet.Draw();
            }

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
