using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace GameLibrary//
{
    public class Sprite
    {
        private ContentManager p_content;
        private SpriteBatch p_spriteBatch;
        public Texture2D image;
        public Vector2 position;
        public Vector2 velocityLinear;
        public Color color;
        public float rotation;
        public float velocityAngular;
        public Vector2 scaleV;
        public Vector2 origin;
        public bool alive;
        public bool visible;

        public Sprite(ContentManager content, SpriteBatch spriteBatch)
        {
            p_content = content;
            p_spriteBatch = spriteBatch;
            image = null;
            position = Vector2.Zero;
            velocityLinear = Vector2.Zero;
            color = Color.White;
            rotation = 0.0f;
            velocityAngular = 0.0f;
            scaleV = new Vector2(1.0f);
            origin = Vector2.Zero;
            alive = true;
            visible = true;
        }

        public float scale
        {
            get { return scaleV.X; }
            set
            {
                scaleV.X = value;
                scaleV.Y = value;
            }
        }

        public bool Load(string assetName)
        {
            try
            {
                image = p_content.Load<Texture2D>(assetName);
                origin = new Vector2(image.Width / 2, image.Height / 2);
            }
            catch (Exception) { return false; }
            return true;
        }

        public void Draw()
        {
            p_spriteBatch.Draw(image, position, null, color, rotation,
                origin, scaleV, SpriteEffects.None, 0.0f);
        }

        public void Move()
        {
            position += velocityLinear;
        }

        public void Rotate()
        {
            rotation += velocityAngular;
            if (rotation > Math.PI * 2)
                rotation -= (float)Math.PI * 2;
            else if (rotation < 0.0f)
                rotation = (float)Math.PI * 2 - rotation;
        }

        public Rectangle Boundary()
        {
            int halfw = (int)( (float)(image.Width / 2) * scaleV.X );
            int halfh = (int)( (float)(image.Height / 2) * scaleV.Y );
            
            return new Rectangle(
                (int)position.X - halfw,
                (int)position.Y - halfh,
                halfw * 2,
                halfh * 2);
        }

        public override string ToString()
        {
            string s = "Texture {W:" + image.Width.ToString() +
                " H:" + image.Height.ToString() + "}\n" +
                "Position {X:" + position.X.ToString("N2") + " Y:" +
                    position.Y.ToString("N2") + "}\n" +
                "Lin Vel " + velocityLinear.ToString() + "\n" +
                "Ang Vel {" + velocityAngular.ToString("N2") + "}\n" +
                "Scaling " + scaleV.ToString() + "\n" +
                "Rotation " + rotation.ToString() + "\n" +
                "Pivot " + origin.ToString() + "\n";
                Rectangle B = Boundary();
                s += "Boundary {X:" + B.X.ToString() + " Y:" + 
                    B.Y.ToString() + " W:" + B.Width.ToString() + 
                    " H:" + B.Height.ToString() + "}\n";

            return s;            
        }
    }
}
