using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Color_Animation_Demo
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;
        Texture2D shapeImage;
        List<Sprite> shapes;

        CycleColor cycleRed, cycleGreen, cycleBlue;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            shapeImage = Content.Load<Texture2D>("box");

            Sprite redBox = new Sprite(Content, spriteBatch);
            redBox.image = shapeImage;
            redBox.position = new Vector2(200, 240);
            redBox.origin = new Vector2(64, 64);
            redBox.velocityAngular = 0.05f;
            redBox.color = new Color(255, 0, 0);

            Sprite greenBox = new Sprite(Content, spriteBatch);
            greenBox.image = shapeImage;
            greenBox.position = new Vector2(400, 240);
            greenBox.origin = new Vector2(64, 64);
            greenBox.velocityAngular = 0.05f;
            greenBox.color = new Color(0, 255, 0);

            Sprite blueBox = new Sprite(Content, spriteBatch);
            blueBox.image = shapeImage;
            blueBox.position = new Vector2(600, 240);
            blueBox.origin = new Vector2(64, 64);
            blueBox.velocityAngular = 0.05f;
            blueBox.color = new Color(0, 0, 255);


            cycleRed = new CycleColor(-1, 0, 0, 0);
            redBox.SetAnimation(cycleRed);

            cycleGreen = new CycleColor(0, -1, 0, 0);
            greenBox.SetAnimation(cycleGreen);

            cycleBlue = new CycleColor(0, 0, -1, 0);
            blueBox.SetAnimation(cycleBlue);
            

            shapes = new List<Sprite>();
            shapes.Add(redBox);
            shapes.Add(greenBox);
            shapes.Add(blueBox);


        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];

                if (touch.State == TouchLocationState.Pressed &&
                    oldTouch.State == TouchLocationState.Released)
                {
                }
                oldTouch = touch;
            }

            foreach (Sprite spr in shapes)
            {
                spr.Rotate();
                spr.Move();
            }

            if (!cycleBlue.animating)
            {
                cycleBlue.blue *= -1;
                cycleBlue.animating = true;
            }

            if (!cycleGreen.animating)
            {
                cycleGreen.green *= -1;
                cycleGreen.animating = true;
            }

            if (!cycleRed.animating)
            {
                cycleRed.red *= -1;
                cycleRed.animating = true;
            }


            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in shapes)
            {
                spr.Animate();
                spr.Draw();
            }

            spriteBatch.DrawString(font, "Color Animation Demo", new Vector2(0, 0), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
        

    }


}
