using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Animation_Mods
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;
        List<Sprite> objects;
        Sprite swordsman, skelly, dragon;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            //create object list
            objects = new List<Sprite>();

            //create swordsman sprite
            swordsman = new Sprite(Content, spriteBatch);
            swordsman.Load("swordsman_walking");
            swordsman.position = new Vector2(150, 240);
            swordsman.size = new Vector2(96, 96);
            swordsman.columns = 8;
            swordsman.totalFrames = 64;
            swordsman.animations.Add(new FrameLoop(0, 63, 1));
            swordsman.animations.Add(new ThrobBounce(0.5f, 4.0f, 0.1f));
            objects.Add(swordsman);

            //create skeleton sprite
            skelly = new Sprite(Content, spriteBatch);
            skelly.Load("skeleton_attack");
            skelly.position = new Vector2(425, 240);
            skelly.size = new Vector2(96,96);
            skelly.scale = 2.0f;
            skelly.columns = 10;
            skelly.totalFrames = 80;
            skelly.animations.Add(new FrameLoop(0, 79, 1));
            skelly.animations.Add(new CycleColorBounce(1, 2, 2, 0));
            objects.Add(skelly);
            
            //create dragon sprite
            dragon = new Sprite(Content, spriteBatch);
            dragon.Load("dragon");
            dragon.position = new Vector2(700, 240);
            dragon.size = new Vector2(128, 128);
            dragon.scale = 1.5f;
            dragon.columns = 8;
            dragon.totalFrames = 64;
            dragon.animations.Add(new FrameBounce(48, 55, 1));
            dragon.animations.Add(new OrbitalMovement(dragon.position, 50, 0, 0.1f));
            objects.Add(dragon);
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                }
                oldTouch = touch;
            }

            //update all objects
            foreach (Sprite spr in objects)
            {
                spr.Rotate();
                spr.Move();
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin();

            foreach (Sprite spr in objects)
            {
                //do color/transform mods
                spr.Animate();

                //do frame animation
                //spr.Animate(gameTime.ElapsedGameTime.Milliseconds);

                spr.Draw();
            }

            spriteBatch.DrawString(font, "", Vector2.Zero, Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
