using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

/*
 * Add Reference, .NET, System.Device
 */
using System.Device.Location;


namespace Geo_Position_Demo
{
    
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        TouchLocation oldTouch;
        Random rand;
        SpriteFont font;

        string statusText = "";
        GeoCoordinateWatcherSim watcher = null;
        GeoCoordinate coord = null;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
        }

        protected override void Initialize()
        {
            base.Initialize();

            StartGeoLocation();
        }

        protected override void LoadContent()
        {
            rand = new Random();
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");
            coord = new GeoCoordinate();
        }

        protected override void UnloadContent()
        {
            base.UnloadContent();

            watcher.Stop();
        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            //get state of touch input
            TouchCollection touchInput = TouchPanel.GetState();
            if (touchInput.Count > 0)
            {
                TouchLocation touch = touchInput[0];
                if (touch.State == TouchLocationState.Pressed)
                {
                }
                oldTouch = touch;
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);
            spriteBatch.Begin(SpriteSortMode.FrontToBack, 
                BlendState.AlphaBlend);

            spriteBatch.DrawString(font, "Latitude: " + 
                coord.Latitude.ToString("0.000"),
                new Vector2(100, 10), Color.White);

            spriteBatch.DrawString(font, "Longitude: " + 
                coord.Longitude.ToString("0.000"), 
                new Vector2(100, 30), Color.White);

            spriteBatch.DrawString(font, statusText, 
                new Vector2(100, 100), Color.White);

            spriteBatch.End();
            base.Draw(gameTime);
        }

        void StartGeoLocation()
        {
            //try to create geo coordinate watcher
            if (watcher == null)
            {
                statusText += "Starting location service...\n";
                watcher = new GeoCoordinateWatcherSim(
                    GeoPositionAccuracy.Default);
                watcher.MovementThreshold = 20;
                watcher.StatusChanged += new EventHandler
                    <GeoPositionStatusChangedEventArgs>(
                    watcher_StatusChanged);
                watcher.PositionChanged += new EventHandler
                    <GeoPositionChangedEventArgs<GeoCoordinate>>
                    (watcher_PositionChanged);
                watcher.Start();
            }
        }

        void watcher_StatusChanged(object sender, 
            GeoPositionStatusChangedEventArgs e)
        {
            switch (e.Status)
            {
                case GeoPositionStatus.Disabled:
                    statusText += "Location service has been disabled\n";
                    break;

                case GeoPositionStatus.Initializing:
                    statusText += "Location service is initializing\n";
                    break;

                case GeoPositionStatus.NoData:
                    statusText += "Location service is not returning any data\n";
                    break;

                case GeoPositionStatus.Ready:
                    statusText += "Location service is receiving data\n";
                    break;
            }
        }

        void watcher_PositionChanged(object sender, 
            GeoPositionChangedEventArgs<GeoCoordinate> e)
        {
            coord = e.Position.Location;
        }
    }

}
