using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Black_Hole_Game
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        public enum GameStates
        {
            TITLE = 0,
            PLAYING = 1,
            OPTIONS = 2,
            GAMEOVER = 3
        }

        public GraphicsDeviceManager graphics;
        public SpriteBatch spriteBatch;
        public GameStates gameState;
        SpriteFont font;
        Random rand;
        TouchLocation oldTouch;
        IGameModule[] modules;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            oldTouch = new TouchLocation();
            rand = new Random();
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            font = Content.Load<SpriteFont>("WascoSans");

            modules = new IGameModule[4];
            modules[0] = new TitleScreenModule(this);
            modules[1] = new PlayingModule(this);
            modules[2] = new OptionsModule(this);
            modules[3] = new GameOverModule(this);

            foreach (IGameModule mod in modules)
            {
                mod.LoadContent(Content);
            }

            gameState = GameStates.TITLE;


        }

        protected override void Update(GameTime gameTime)
        {
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back ==
                ButtonState.Pressed)
                this.Exit();

            TouchCollection touchInput = TouchPanel.GetState();
            TouchLocation touch = new TouchLocation();
            if (touchInput.Count > 0)
            {
                touch = touchInput[0];
                oldTouch = touch;
            }


            //update current module
            modules[(int)gameState].Update(touch ,gameTime);


            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin(SpriteSortMode.Deferred, BlendState.AlphaBlend);

            //draw current module
            modules[(int)gameState].Draw(gameTime);

            spriteBatch.End();
            base.Draw(gameTime);
        }

    }
}
