using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using GameLibrary;

namespace Black_Hole_Game
{
    public class PlayingModule : IGameModule
    {
        Game1 game;
        SpriteFont font;
        Random rand;
        MassiveObject blackHole;
        MassiveObject asteroid;
        MassiveObject plasma;

        public PlayingModule(Game1 game)
        {
            this.game = game;
            rand = new Random();
        }

        public void LoadContent(ContentManager content)
        {
            font = content.Load<SpriteFont>("WascoSans");

            blackHole = new MassiveObject(game.Content, game.spriteBatch);
            blackHole.Load("blackhole");
            blackHole.position = new Vector2(400, 240);
            blackHole.velocityAngular = -.05f;
            blackHole.scale = 1.0f;
            blackHole.mass = 100;

            asteroid = new MassiveObject(game.Content, game.spriteBatch);
            asteroid.Load("asteroid");
            asteroid.columns = 8;
            asteroid.totalFrames = 64;
            asteroid.size = new Vector2(60, 60);
            asteroid.radius = 80;
            asteroid.animations.Add(new OrbitalMovement(new Vector2(400,240), 80, 0, 0.08f));
            asteroid.scale = 0.5f;

            plasma = new MassiveObject(game.Content, game.spriteBatch);
            plasma.Load("plasma32");
            plasma.position = new Vector2(200, 240);
            plasma.mass = 1;
            plasma.velocityLinear = new Vector2(1.0f, 7.0f);
            
        }

        public void Update(TouchLocation touch, GameTime gameTime)
        {
            int time = gameTime.ElapsedGameTime.Milliseconds;

            blackHole.Update(gameTime);
            blackHole.Rotate();

            asteroid.angle += 0.001f;
            asteroid.Update(gameTime);
            asteroid.Rotate();
            asteroid.Animate(time);
            asteroid.Animate();

            plasma.Update(gameTime);
            //see if object has gone too far out of bounds
            if (plasma.position.X < -500 || plasma.position.X > 1300) 
                plasma.position.X *= -1;
            if (plasma.position.Y < -500 || plasma.position.Y > 960) 
                plasma.position.Y *= -1;

            plasma.Rotate();
            plasma.Animate();
            if (!plasma.captured)
            {
                plasma.Attract(blackHole);

                if (game.RadialCollision(plasma, blackHole))
                {
                    plasma.captured = true;
                    OrbitalMovement anim1 = new OrbitalMovement(blackHole.position,
                        20 + rand.Next(20), plasma.rotation, 0.8f);
                    plasma.animations.Add(anim1);
                    CycleColorBounce anim2 = new CycleColorBounce(0, 10, 10, 0);
                    plasma.animations.Add(anim2);
                }
            }
                
        }

        public void Draw(GameTime gameTime)
        {
            blackHole.Draw();
            asteroid.Draw();
            plasma.Draw();

            string text = "Position " + 
                ((int)plasma.position.X).ToString() + "," +
                ((int)plasma.position.Y).ToString();
            game.spriteBatch.DrawString(font, text, new Vector2(0, 0), Color.White);

            float dist = game.Distance(plasma.position, blackHole.position);
            text = "Distance " + ((int)dist).ToString();
            game.spriteBatch.DrawString(font, text, new Vector2(0, 20), Color.White);

        }
    }
}
